@@ -68,6 +68,10 @@
 #include "as_gfx/rowdel.xpm"    // static const char *s_kpcRowdel_xpm[]
 #include "as_gfx/osspicon.xpm"  // static const char *s_kpcOsspicon_xpm[]
 #include "as_gfx/whatsthis.xpm" // static const char *s_kpcWhatsthis_xpm[]
+#include "as_gfx/statok.xpm"    // static const char *s_kpcStatokay_xpm[]
+#include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
+#include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
+#include "as_gfx/statvoid.xpm"  // static const char *s_kpcStatvoid_xpm[]
 
 
 //
@@ -478,6 +482,7 @@ void Titraqform::setupTable(void)
         throw Genexcept("Main window table creation failed.");
     m_pMaintable->setNumCols(TITRAQ_IDXTAIL);
     m_pMaintable->setReadOnly(true);                    // Table is read only
+    m_pMaintable->setEnabled(false);                    // Table starts disabled
     m_pMaintable->setColumnMovingEnabled(false);        // Ctrl-drag disabled
     m_pMaintable->setSelectionMode(QTable::MultiRow);   // Multi row selection
     m_pMaintable->setCurrentCell(-1, 0);                // Initial row value -1
@@ -488,7 +493,7 @@ void Titraqform::setupTable(void)
     m_pMaintable->horizontalHeader()->setClickEnabled(true); // Allow click signals
     m_pMaintable->horizontalHeader()->setTracking(false); // No continuous tracking
     m_pMaintable->setColumnStretchable(TITRAQ_IDXTAIL - 1, true);
-    m_pMaintable->setSorting(false);
+    m_pMaintable->setSorting(true);
 
     // Table header row
     m_pTablehead = m_pMaintable->horizontalHeader();
@@ -526,6 +531,7 @@ void Titraqform::setupTable(void)
 
     // Table update signals
     connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(updEdit(int, int)));
+    connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(validateData(int, int)));
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
     connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(void)));
@@ -541,14 +547,11 @@ void Titraqform::setupEditlay(void)
 //    m_pEditlayout->addWidget(&Pad); // Padd left side of control layout
 
     // Make the status edit
-    m_pStatusedit = new QLineEdit(m_pCenframe, "Status");
+    m_pStatusedit = new QLabel(m_pCenframe, "Status");
     if (m_pStatusedit == NULL) // Sanity check
         throw Genexcept("Main window status edit creation failed.");
-    m_pStatusedit->setText(trUtf8("0"));
-    m_pStatusedit->setFrameShape(QLineEdit::LineEditPanel);
-    m_pStatusedit->setFrameShadow(QLineEdit::Sunken);
-    m_pStatusedit->setFrame(true);
-    m_pStatusedit->setReadOnly(true);
+    m_pStatusedit->setPixmap(QPixmap(s_kpcStatvoid_xpm));   // Placeholder
+
     QToolTip::add(m_pStatusedit, trUtf8("Status Item"));
     m_pEditlayout->addWidget(m_pStatusedit);  // Finally add the item status edit
 
@@ -562,11 +565,11 @@ void Titraqform::setupEditlay(void)
     m_pLineedit = new QLineEdit(m_pCenframe, "Lineno");
     if (m_pLineedit == NULL) // Sanity check
         throw Genexcept("Main window line number edit creation failed.");
-    m_pLineedit->setText(trUtf8("0"));
     m_pLineedit->setFrameShape(QLineEdit::LineEditPanel);
     m_pLineedit->setFrameShadow(QLineEdit::Sunken);
     m_pLineedit->setFrame(true);
     m_pLineedit->setReadOnly(true);
+    m_pLineedit->setEnabled(false);
     m_pLineedit->setAlignment(Qt::AlignRight);
     QToolTip::add(m_pLineedit, trUtf8("Line Number"));
     m_pEditlayout->addWidget(m_pLineedit);  // Finally add the line number edit
@@ -581,11 +584,11 @@ void Titraqform::setupEditlay(void)
     m_pUseredit = new QLineEdit(m_pCenframe, "User");
     if (m_pUseredit == NULL) // Sanity check
         throw Genexcept("Main window user edit creation failed.");
-    m_pUseredit->setText(m_pPrefs->getString(TITRAQ_PREFUSER, TITRAQ_DEFUSER));
     m_pUseredit->setFrameShape(QLineEdit::LineEditPanel);
     m_pUseredit->setFrameShadow(QLineEdit::Sunken);
     m_pUseredit->setFrame(true);
     m_pUseredit->setReadOnly(false);
+    m_pUseredit->setEnabled(false);
     QToolTip::add(m_pUseredit, trUtf8("User Name"));
     m_pEditlayout->addWidget(m_pUseredit);  // Finally add the user edit
 
@@ -599,11 +602,11 @@ void Titraqform::setupEditlay(void)
     m_pGuidedit = new QLineEdit(m_pCenframe, "Guid");
     if (m_pGuidedit == NULL) // Sanity check
         throw Genexcept("Main window GUID edit creation failed.");
-    m_pGuidedit->setText(trUtf8("."));
     m_pGuidedit->setFrameShape(QLineEdit::LineEditPanel);
     m_pGuidedit->setFrameShadow(QLineEdit::Sunken);
     m_pGuidedit->setFrame(true);
     m_pGuidedit->setReadOnly(true);
+    m_pGuidedit->setEnabled(false);
     QToolTip::add(m_pGuidedit, trUtf8("GUID"));
     m_pEditlayout->addWidget(m_pGuidedit);  // Finally add the GUID edit
 
@@ -617,11 +620,11 @@ void Titraqform::setupEditlay(void)
     m_pCrcedit = new QLineEdit(m_pCenframe, "Crc");
     if (m_pCrcedit == NULL) // Sanity check
         throw Genexcept("Main window CRC edit creation failed.");
-    m_pCrcedit->setText(trUtf8("."));
     m_pCrcedit->setFrameShape(QLineEdit::LineEditPanel);
     m_pCrcedit->setFrameShadow(QLineEdit::Sunken);
     m_pCrcedit->setFrame(true);
     m_pCrcedit->setReadOnly(true);
+    m_pCrcedit->setEnabled(false);
     QToolTip::add(m_pCrcedit, trUtf8("CRC"));
     m_pEditlayout->addWidget(m_pCrcedit);  // Finally add the CRC edit
 
@@ -635,11 +638,11 @@ void Titraqform::setupEditlay(void)
     m_pRevedit = new QLineEdit(m_pCenframe, "Revision");
     if (m_pRevedit == NULL) // Sanity check
         throw Genexcept("Main window revision edit creation failed.");
-    m_pRevedit->setText(trUtf8("."));
     m_pRevedit->setFrameShape(QLineEdit::LineEditPanel);
     m_pRevedit->setFrameShadow(QLineEdit::Sunken);
     m_pRevedit->setFrame(true);
     m_pRevedit->setReadOnly(true);
+    m_pRevedit->setEnabled(false);
     QToolTip::add(m_pRevedit, trUtf8("Revision"));
     m_pEditlayout->addWidget(m_pRevedit);  // Finally add the revision edit
 
@@ -659,6 +662,7 @@ void Titraqform::setupEditlay(void)
     m_pDateedit->setOrder(QDateEdit::YMD);
     m_pDateedit->setAutoAdvance(true);
     m_pDateedit->setSeparator(trUtf8("."));
+    m_pDateedit->setEnabled(false);
 
     m_pEditlayout->addWidget(m_pDateedit);                          // Finally add the date editor
     QToolTip::add(m_pDateedit, trUtf8("Task Date"));
@@ -675,9 +679,11 @@ void Titraqform::setupEditlay(void)
         throw Genexcept("Main window start time creation failed."); // Spew errors
 
     // Configure attributes
+    m_pStarttime->setDisplay(QTimeEdit::Hours | QTimeEdit::Minutes);
     m_pStarttime->setAutoAdvance(true);
+    m_pStarttime->setEnabled(false);
 
-    m_pEditlayout->addWidget(m_pStarttime);                      // Finally add the start editor
+    m_pEditlayout->addWidget(m_pStarttime);                         // Finally add the start editor
     QToolTip::add(m_pStarttime, trUtf8("Task Starting Time"));
 
     // Whatsthis info for the time editor
@@ -688,10 +694,15 @@ void Titraqform::setupEditlay(void)
 
     // Make the end time selector
     m_pEndtime = new QTimeEdit(m_pCenframe, "EndTime");
-    if (m_pEndtime == NULL)                                        // Sanity check
-        throw Genexcept("Main window end time creation failed.");  // Spew errors
+    if (m_pEndtime == NULL)                                         // Sanity check
+        throw Genexcept("Main window end time creation failed.");   // Spew errors
 
-    m_pEditlayout->addWidget(m_pEndtime);                       // Finally add the end editor
+    // Configure attributes
+    m_pEndtime->setDisplay(QTimeEdit::Hours | QTimeEdit::Minutes);
+    m_pEndtime->setAutoAdvance(true);
+    m_pEndtime->setEnabled(false);
+
+    m_pEditlayout->addWidget(m_pEndtime);                           // Finally add the end editor
     QToolTip::add(m_pEndtime, trUtf8("Task Ending Time"));
 
     // Whatsthis info for the time editor
@@ -708,6 +719,7 @@ void Titraqform::setupEditlay(void)
     // Configure attributes
     m_pAmount->setButtonSymbols(QSpinBox::PlusMinus);
     m_pAmount->setSuffix(trUtf8(" Minutes"));
+    m_pAmount->setEnabled(false);
 //    m_pAmount->setSpecialValueText(trUtf8("In progress"));
 
     m_pEditlayout->addWidget(m_pAmount);    // Finally add the amount editor
@@ -743,6 +755,7 @@ void Titraqform::setupEditlay(void)
     m_pTasks->setCurrentText(NULL);
     m_pTasks->setAutoCompletion(true);
     m_pTasks->setDuplicatesEnabled(false);
+    m_pTasks->setEnabled(false);
 //    m_pTasks->setEditable(false);   // Only idiots define noneditable and autocompletion
 
     // Add an auto scroll bar if possible under current GUI style
@@ -760,11 +773,11 @@ void Titraqform::setupEditlay(void)
     m_pRemark = new QLineEdit(m_pCenframe, "Remark");
     if (m_pRemark == NULL)  // Sanity check
         throw Genexcept("Main window remark line creation failed.");
-    m_pRemark->setText(trUtf8("Happy birthday to Ralf"));
     m_pRemark->setFrameShape(QLineEdit::LineEditPanel);
     m_pRemark->setFrameShadow(QLineEdit::Sunken);
     m_pRemark->setFrame(true);
     m_pRemark->setReadOnly(false);
+    m_pRemark->setEnabled(false);
     QToolTip::add(m_pRemark, trUtf8("Remark Line"));
     m_pEditlayout->addWidget(m_pRemark);    // Finally add the remark line
 
@@ -778,7 +791,6 @@ void Titraqform::setupEditlay(void)
     this->updSizes(TITRAQ_IDXALLCTRLS, -1, -1);
 
     // Signals sent between table cells and corresponding edit control widgets
-    connect(m_pStatusedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateStatus(const QString &)));
     connect(m_pLineedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateLine(const QString &)));
     connect(m_pUseredit, SIGNAL(textChanged(const QString &)), this, SLOT(updateUser(const QString &)));
     connect(m_pGuidedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateGuid(const QString &)));
