@@ -42,6 +42,8 @@
 #include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
 #include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
 
+#include <iostream>
+
 //
 // Convenience method to load accounting data from a file
 //
@@ -71,6 +73,10 @@ void Titraqform::loadData(QTextStream &Tstream)
     QString Line;       // Used for linewise editing and whitespace eating
     QString Bitbucket;  // Used for null device until we find a better way
 
+    QPixmap Statokay(s_kpcStatokay_xpm);
+    QPixmap Statwarn(s_kpcStatwarn_xpm);
+    QPixmap Staterror(s_kpcStaterror_xpm);
+
     // Strip out extra line feeds at stream start
     while (Line.isEmpty() && !Tstream.atEnd())
         Line = Tstream.readLine();
@@ -157,13 +163,19 @@ void Titraqform::loadData(QTextStream &Tstream)
 
         Asline.skipWhiteSpace();    // Remove whitespaces
         Remark = Asline.read();     // Copy the remark field
+
+        // Get rid of surrounding double quotes
+        QRegExp Quoted("\"(.*)\"$");
+        Quoted.search(Remark);
+        Remark = Quoted.cap(Quoted.numCaptures());
+
         if (!Remark.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXREMARK, Remark);
 
         if (bValid) // Show a bitmap to signal valid or error state
-            m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, QPixmap(s_kpcStatokay_xpm));
+            m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, Statokay);
         else
-            m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, QPixmap(s_kpcStaterror_xpm));
+            m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, Staterror);
 
         // Insert a line number dynamically
         m_pMaintable->setText(nIter, TITRAQ_IDXLINE, (QString::number(nIter)).rightJustify(4, QChar('0')));
@@ -216,6 +228,9 @@ void Titraqform::saveData(QTextStream &Tstream)
     QString Strsearch;                              // String to strip search
     QRegExp Stripper("\\s*$");                      // Pattern to strip off
 
+    // Optimize viewing by repainting cells only once after processing
+    m_pMaintable->setUpdatesEnabled(false);
+
     // Linewise save from the main table date, time, account, and others
     for (int nIter = 0; nIter < nRows; nIter++) {
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXUSER);      // Load user field text
@@ -259,11 +274,13 @@ void Titraqform::saveData(QTextStream &Tstream)
             Strsearch = QRegExp::escape(Tempfield);                 // Incoming string escaped
             Stripper.search(Strsearch);
             Tempfield.truncate(Stripper.pos());
-            Tstream << trUtf8(" ") << Tempfield;                    // Save remark field text
+            Tstream << trUtf8(" \"") << Tempfield << trUtf8("\"");  // Save remark field text
         }
 
         Tstream << endl;                                            // Append a newline
     }
+
+    m_pMaintable->setUpdatesEnabled(true); // Update and repaint
 }
 
 //
@@ -278,10 +295,10 @@ const QString Titraqform::getRowdata(void) const
     // Calculate rows to delete from selection highlight
     for (int nIter = 0; nIter < nTotal; ++nIter) {
         // Build the row data string one field at a time, adding seps inbetween
+        Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXUSER);
+        Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXDATE);
         Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
-    //    Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXUSER);
-    //    Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXSTART);
         Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXFINISH);
@@ -305,18 +322,18 @@ void Titraqform::setRowdata(QString &Rowdata) const
     int nRows = Rowdata.contains(QChar('\n'));          // Set so many rows
     int nCurrentrow = m_pMaintable->currentRow();       // Current table row
     QTableItem *pItem = NULL;                           // Old item to change out
-    QString Date, Start, Finish, Amount, Task, Remark;  // Text fields in table
+    QString User;                                       // Admin fields in table
+    QString Date, Start, Finish, Amount, Task, Remark;  // Viewable fields in table
     QTextStream Datastream(&Rowdata, IO_ReadOnly);      // Convert data to stream
 
     for (int nIter = 0; nIter < nRows; ++nIter) {
-        Datastream >> Date >> Start;                    // Stream data fields
+        Datastream >> User >> Date >> Start;            // Stream data fields
         Datastream >> Finish >> Amount >> Task;         // to corresponding vars
-        Datastream.skipWhiteSpace();                    // Remove whitespaces
         Remark = Datastream.readLine();                 // Remark is a whole line
 
         // Set the table row data one field at a time, skipping seps inbetween
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXUSER, User);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXDATE, Date);
-//        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXUSER, User);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXSTART, Start);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXFINISH, Finish);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXAMOUNT, Amount);
@@ -333,6 +350,7 @@ void Titraqform::setRowdata(QString &Rowdata) const
         m_pMaintable->setItem(nCurrentrow + nIter, TITRAQ_IDXTASK, new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Task));
 
         // Continue with field processing business as usual
+        Remark.simplifyWhiteSpace(); // First get rid of and simplify whitespace
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXREMARK, Remark);
     }
 }
