@@ -32,9 +32,9 @@
 // Qt headers
 #include <qfiledialog.h>
 #include <qcombobox.h>
-#include <qregexp.h>
 #include <qclipboard.h>
 #include <qmenudata.h>
+//#include <qregexp.h>
 
 // User interface
 #include "as_gui.h"             // Main classes
@@ -45,6 +45,9 @@
 // Icon pixel maps
 #include "as_gfx/cwlogo.xpm"    // static const char *s_kpcCwlogo_xpm[]
 #include "as_gfx/ossplogo.xpm"  // static const char *s_kpcOssplogo_xpm[]
+#include "as_gfx/statok.xpm"    // static const char *s_kpcStatokay_xpm[]
+#include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
+#include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
 
 
 //
@@ -82,12 +85,18 @@ void Titraqform::pasteEntry(void)
     QString Selection;          // Will receive the clipboard text
     QClipboard *pClip;          // Will reference the global clipboard
 
-    Selection = pClip->text(QClipboard::Clipboard); // Windows and Unix
-    nRows = Selection.contains(QChar('\n'));        // How many rows
-    this->addEntry(nRows);                          // Reuse slot
+    // Optimize viewing by repainting cells only once after processing
+    m_pMaintable->setUpdatesEnabled(false);
 
-    if (Selection)
+    if (Selection = pClip->text(QClipboard::Clipboard)) { // Windows and Unix
+        nRows = Selection.contains(QChar('\n'));    // How many rows
+        this->addEntry(nRows);                      // Reuse slot
         setRowdata(Selection);                      // Use accessor
+        for (int nIter = 0; nIter <= nRows; nIter++)
+            this->validateData(m_pMaintable->currentRow() + nIter, 0);
+    }
+
+    m_pMaintable->setUpdatesEnabled(true);          // Update and repaint
 }
 
 //
@@ -99,25 +108,62 @@ void Titraqform::addEntry(int nRows)
     int nTotal = 0;         // Total row select
     int nCurrent = 0;       // Current row
 
+    // Decide how many rows to add
     Select = m_pMaintable->selection(0);
-    nTotal = Select.bottomRow() - Select.topRow() + 1;
+    if (nRows > 0)
+        nTotal = nRows;
+    else
+        nTotal = Select.bottomRow() - Select.topRow() + 1;
+
+    // Optimize viewing by repainting cells only once after processing
+    m_pMaintable->setUpdatesEnabled(false);
+
     // Add a row after selection and focus to the new row
     if (Select.bottomRow() + 1 != m_pMaintable->numRows()) { // Add upwards
         m_pMaintable->insertRows(Select.topRow(), nTotal);
         this->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.topRow(), m_pMaintable->currentColumn());
+
+        // Update relevant data fields for all new rows
+        for (int nIter = 0; nIter < nTotal; nIter++) {
+            m_pMaintable->setPixmap(Select.topRow() + nIter, TITRAQ_IDXSTATUS, QPixmap(s_kpcStatwarn_xpm));
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXUSER, m_pPrefs->getString(TITRAQ_PREFUSER, TITRAQ_DEFUSER));
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXGUID, ".");
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXCRC, ".");
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXREV, ".");
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXDATE, trUtf8(TITRAQ_DATEZERO));
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXSTART, "00:00");
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXFINISH, "00:00");
+            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXAMOUNT, "00:00");
+//            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXTASK, "/");
+//            m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXREMARK, "Remark");
+        }
     }
     else { // Special case on last row add downwards
         m_pMaintable->insertRows(Select.bottomRow() + 1, nTotal);
         this->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.bottomRow() + 1, m_pMaintable->currentColumn());
         m_pMaintable->ensureCellVisible(m_pMaintable->numRows() - 1, 0); // Scroll please
+
+        // Update relevant data fields for all new rows
+        for (int nIter = 1; nIter <= nTotal; nIter++) {
+            m_pMaintable->setPixmap(Select.bottomRow() + nIter, TITRAQ_IDXSTATUS, QPixmap(s_kpcStatwarn_xpm));
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXUSER, m_pPrefs->getString(TITRAQ_PREFUSER, TITRAQ_DEFUSER));
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXGUID, ".");
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXCRC, ".");
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXREV, ".");
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXDATE, trUtf8(TITRAQ_DATEZERO));
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXSTART, "00:00");
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXFINISH, "00:00");
+            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXAMOUNT, "00:00");
+//            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXTASK, "/");
+//            m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXREMARK, "Remark");
+        }
     }
 
-//    updateDate(*m_pDatezero);
-//    updateStart(QTime::QTime(0, 0));
-//    updateFinish(QTime::QTime(0, 0));
-//    updateAmount(trUtf8("00:00"));
+    // Update line numbers for this new row and all subsequent rows
+    for (int nIter = m_pMaintable->currentRow(); nIter < m_pMaintable->numRows(); nIter++)
+        m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
 
 //    char szGuitext[37];
 //    uuid_t Guid;
@@ -125,6 +171,9 @@ void Titraqform::addEntry(int nRows)
 //    uuid_generate(Guid);
 //    uuid_unparse(Guid, szGuitext);
 //    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXGUID, szGuitext);
+
+    m_pMaintable->setUpdatesEnabled(true);          // Turn updates back on
+    m_pMaintable->repaintContents(false);           // Repaint viewport
 }
 
 //
@@ -150,6 +199,10 @@ void Titraqform::delEntry(int nRows)
         m_pMaintable->removeRows(Rowselect);
         this->setDirty();   // Set data to dirty state
     }
+
+    // Update line numbers for this new row and all subsequent rows
+    for (int nIter = m_pMaintable->currentRow(); nIter < m_pMaintable->numRows(); nIter++)
+        m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter));
 }
 
 //
@@ -177,11 +230,37 @@ void Titraqform::newDoc(void)
             m_pTasks->setCurrentText(NULL);
             m_pRemark->setText(NULL);
 
+            m_pMaintable->setEnabled(true); // Enable the table first
             m_pMaintable->setNumRows(0);    // Remove all data in table
+            m_pLineedit->setEnabled(true);
+            m_pUseredit->setEnabled(true);
+            m_pGuidedit->setEnabled(true);
+            m_pCrcedit->setEnabled(true);
+            m_pRevedit->setEnabled(true);
+            m_pDateedit->setEnabled(true);
+            m_pStarttime->setEnabled(true);
+            m_pEndtime->setEnabled(true);
+            m_pAmount->setEnabled(true);
+            m_pTasks->setEnabled(true);
+            m_pRemark->setEnabled(true);
+            this->updEdit(0, 0);            // Reset edit controls
             this->setDirty(false);          // Reset data to clean state
             break;
         case 1: // Second button selected, so don't save first but do new
+            m_pMaintable->setEnabled(true); // Enable the table first
             m_pMaintable->setNumRows(0);    // Remove all data in table
+            m_pLineedit->setEnabled(true);
+            m_pUseredit->setEnabled(true);
+            m_pGuidedit->setEnabled(true);
+            m_pCrcedit->setEnabled(true);
+            m_pRevedit->setEnabled(true);
+            m_pDateedit->setEnabled(true);
+            m_pStarttime->setEnabled(true);
+            m_pEndtime->setEnabled(true);
+            m_pAmount->setEnabled(true);
+            m_pTasks->setEnabled(true);
+            m_pRemark->setEnabled(true);
+            this->updEdit(0, 0);            // Reset edit controls
             this->setDirty(false);          // Reset data to clean state
             break;
         case 2: // Third button selected, so don't do a new timesheet
@@ -197,7 +276,20 @@ void Titraqform::newDoc(void)
         m_pAmount->setText(NULL);
         m_pTasks->setCurrentText(NULL);
         m_pRemark->setText(NULL);
+        m_pMaintable->setEnabled(true);     // Enable the table first
         m_pMaintable->setNumRows(0);        // Remove all data in table
+        m_pLineedit->setEnabled(true);
+        m_pUseredit->setEnabled(true);
+        m_pGuidedit->setEnabled(true);
+        m_pCrcedit->setEnabled(true);
+        m_pRevedit->setEnabled(true);
+        m_pDateedit->setEnabled(true);
+        m_pStarttime->setEnabled(true);
+        m_pEndtime->setEnabled(true);
+        m_pAmount->setEnabled(true);
+        m_pTasks->setEnabled(true);
+        m_pRemark->setEnabled(true);
+        this->updEdit(0, 0);                // Reset edit controls
         this->setDirty(false);              // Reset data to clean state
     }
 }
@@ -232,6 +324,18 @@ void Titraqform::openDoc(void)
                 // Reset and give output to main window
                 this->setCaption(Filestring);
                 m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                m_pMaintable->setEnabled(true); // Enable the table first
+                m_pLineedit->setEnabled(true);
+                m_pUseredit->setEnabled(true);
+                m_pGuidedit->setEnabled(true);
+                m_pCrcedit->setEnabled(true);
+                m_pRevedit->setEnabled(true);
+                m_pDateedit->setEnabled(true);
+                m_pStarttime->setEnabled(true);
+                m_pEndtime->setEnabled(true);
+                m_pAmount->setEnabled(true);
+                m_pTasks->setEnabled(true);
+                m_pRemark->setEnabled(true);
                 this->setDirty(false);          // Set the clean state
                 break;
             case 1: // Don't save first but do load
@@ -246,6 +350,18 @@ void Titraqform::openDoc(void)
                 // Reset and give output to main window
                 this->setCaption(Filestring);
                 m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                m_pMaintable->setEnabled(true); // Enable the table first
+                m_pLineedit->setEnabled(true);
+                m_pUseredit->setEnabled(true);
+                m_pGuidedit->setEnabled(true);
+                m_pCrcedit->setEnabled(true);
+                m_pRevedit->setEnabled(true);
+                m_pDateedit->setEnabled(true);
+                m_pStarttime->setEnabled(true);
+                m_pEndtime->setEnabled(true);
+                m_pAmount->setEnabled(true);
+                m_pTasks->setEnabled(true);
+                m_pRemark->setEnabled(true);
                 this->setDirty(false);          // Set the clean state
                 break;
             case 2: // Don't do a load timesheet
@@ -265,6 +381,18 @@ void Titraqform::openDoc(void)
             // Reset and give output to main window
             this->setCaption(Filestring);
             m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+            m_pMaintable->setEnabled(true); // Enable the table first
+            m_pLineedit->setEnabled(true);
+            m_pUseredit->setEnabled(true);
+            m_pGuidedit->setEnabled(true);
+            m_pCrcedit->setEnabled(true);
+            m_pRevedit->setEnabled(true);
+            m_pDateedit->setEnabled(true);
+            m_pStarttime->setEnabled(true);
+            m_pEndtime->setEnabled(true);
+            m_pAmount->setEnabled(true);
+            m_pTasks->setEnabled(true);
+            m_pRemark->setEnabled(true);
             this->setDirty(false);          // Set the clean state
         }
     }
@@ -514,41 +642,66 @@ void Titraqform::updEdit(int nRow, int nCol)
     // Reset the edition state member
     m_pMaintable->setEdition();
 
-    if (!Textstat.isEmpty())
-        m_pStatusedit->setText(Textstat);
-    if (!Textline.isEmpty())
-        m_pLineedit->setText(Textline);
-    if (!Textuser.isEmpty())
-        m_pUseredit->setText(Textuser);
-    if (!Textguid.isEmpty())
-        m_pGuidedit->setText(Textguid);
-    if (!Textcrc.isEmpty())
-        m_pCrcedit->setText(Textcrc);
-    if (!Textrev.isEmpty())
-        m_pRevedit->setText(Textrev);
+    // Set text of member edit controls
+    m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, nCol));
+    m_pLineedit->setText(Textline);
+    m_pUseredit->setText(Textuser);
+    m_pGuidedit->setText(Textguid);
+    m_pCrcedit->setText(Textcrc);
+    m_pRevedit->setText(Textrev);
+
+    m_pAmount->setText(Textamount);
+//    Texttask.remove(0, Shorten.search(Texttask) + 1); // Strip leading slash
+    m_pTasks->setCurrentText(Texttask);
+    m_pRemark->setText(Textremark);
+
+    // Members not suitable for empty string text
     if (!Textdate.isEmpty())
         m_pDateedit->setDate(QDate::fromString(Textdate, Qt::ISODate));
+    else
+        m_pDateedit->setDate(*m_pDatezero);
     if (!Textstart.isEmpty())
         m_pStarttime->setTime(QTime::fromString(Textstart, Qt::ISODate));
+    else
+        m_pStarttime->setTime(QTime::QTime(0, 0));
     if (!Textfinish.isEmpty())
         m_pEndtime->setTime(QTime::fromString(Textfinish, Qt::ISODate));
-    if (!Textamount.isNull())
-        m_pAmount->setText(Textamount);
-    if (!Texttask.isNull()) { // Process task combo box to compress text length
-//        Texttask.remove(0, Shorten.search(Texttask) + 1); // Strip leading slash
-        m_pTasks->setCurrentText(Texttask);
-    }
-
-    if (!Textremark.isNull())
-        m_pRemark->setText(Textremark);
+    else
+        m_pEndtime->setTime(QTime::QTime(0, 0));
 }
 
 //
-// Update the current status column item
+// Validate one row of matrix data
 //
-void Titraqform::updateStatus(const QString &Instring)
+void Titraqform::validateData(int nRow, int nCol)
 {
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXSTATUS, Instring);
+    if (m_pMaintable->numRows() > 0) {
+        // Field strings to check for validity and process
+        QString Textstat(m_pMaintable->text(nRow, TITRAQ_IDXSTATUS));
+        QString Textline(m_pMaintable->text(nRow, TITRAQ_IDXLINE));
+        QString Textuser(m_pMaintable->text(nRow, TITRAQ_IDXUSER));
+        QString Textguid(m_pMaintable->text(nRow, TITRAQ_IDXGUID));
+        QString Textcrc(m_pMaintable->text(nRow, TITRAQ_IDXCRC));
+        QString Textrev(m_pMaintable->text(nRow, TITRAQ_IDXREV));
+        QString Textdate(m_pMaintable->text(nRow, TITRAQ_IDXDATE));
+        QString Textstart(m_pMaintable->text(nRow, TITRAQ_IDXSTART));
+        QString Textfinish(m_pMaintable->text(nRow, TITRAQ_IDXFINISH));
+        QString Textamount(m_pMaintable->text(nRow, TITRAQ_IDXAMOUNT));
+        QString Texttask(m_pMaintable->text(nRow, TITRAQ_IDXTASK));
+        QString Textremark(m_pMaintable->text(nRow, TITRAQ_IDXREMARK));
+
+        // Quick review of data validity, and set pixmaps accordingly
+        if (Textuser.isEmpty() || Textguid.isEmpty() || Textcrc.isEmpty() ||
+            Textrev.isEmpty() || Textdate.isEmpty() || Textstart.isEmpty() ||
+            Textfinish.isEmpty() || Textamount.isEmpty() || Texttask.isEmpty()) {
+            m_pStatusedit->setPixmap(QPixmap(s_kpcStaterror_xpm));
+            m_pMaintable->setPixmap(nRow, TITRAQ_IDXSTATUS, QPixmap(s_kpcStaterror_xpm));
+        }
+        else {
+            m_pStatusedit->setPixmap(QPixmap(s_kpcStatokay_xpm));
+            m_pMaintable->setPixmap(nRow, TITRAQ_IDXSTATUS, QPixmap(s_kpcStatokay_xpm));
+        }
+    }
 }
 
 //
@@ -599,7 +752,7 @@ void Titraqform::updateDate(const QDate &Dateup)
     if (Dateup == *m_pDatezero) // Complete the already nasty hack
         m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, trUtf8(TITRAQ_DATEZERO));
     else
-        m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, Dateup.toString(Qt::ISODate));
+        m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, Dateup.toString("yyyy.MM.dd"));
 }
 
 //
@@ -607,7 +760,7 @@ void Titraqform::updateDate(const QDate &Dateup)
 //
 void Titraqform::updateStart(const QTime &Startup)
 {
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXSTART, Startup.toString(Qt::ISODate));
+    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXSTART, Startup.toString("hh:mm"));
 }
 
 //
@@ -615,7 +768,7 @@ void Titraqform::updateStart(const QTime &Startup)
 //
 void Titraqform::updateFinish(const QTime &Finishup)
 {
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXFINISH, Finishup.toString(Qt::ISODate));
+    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXFINISH, Finishup.toString("hh:mm"));
 }
 
 //
